@@ -1,4 +1,4 @@
-from python_linq import From, Grouping, NoSuchElementError
+from linq import Query, errors
 import unittest
 
 class TestBasicFunctions(unittest.TestCase):
@@ -15,9 +15,9 @@ class TestBasicFunctions(unittest.TestCase):
         ]
 
     def test_all(self):
-        self.assertFalse(From([1, 2, 3, 4, 5, 6]).all(lambda x: x == 4))
+        self.assertFalse(Query([1, 2, 3, 4, 5, 6]).all(lambda x: x == 4))
 
-        self.assertTrue(From([1, 2, 3, 4, 5, 6]).all(lambda x: x < 7))
+        self.assertTrue(Query([1, 2, 3, 4, 5, 6]).all(lambda x: x < 7))
 
         subject = [
             {
@@ -29,15 +29,15 @@ class TestBasicFunctions(unittest.TestCase):
             }
         ]
         self.assertTrue(
-            From(subject).any(
+            Query(subject).any(
                 lambda x: x["value"] == 2 or x["value"] == 3
             )
         )
 
     def test_any(self):
-        self.assertTrue(From([1, 2, 3, 4, 5, 6]).any(lambda x: x == 4))
+        self.assertTrue(Query([1, 2, 3, 4, 5, 6]).any(lambda x: x == 4))
 
-        self.assertFalse(From([1, 2, 3, 4, 5, 6]).any(lambda x: x > 6))
+        self.assertFalse(Query([1, 2, 3, 4, 5, 6]).any(lambda x: x > 6))
 
         subject = [
             {
@@ -48,17 +48,17 @@ class TestBasicFunctions(unittest.TestCase):
                 "value": 3
             }
         ]
-        self.assertTrue(From(subject).any(lambda x: x["value"] == 2))
+        self.assertTrue(Query(subject).any(lambda x: x["value"] == 2))
 
     def test_average(self):
         subject = [1, 2, 3, 4, 5]
         self.assertEqual(
-            From(subject).average(),
+            Query(subject).mean(),
             3
         )
 
         self.assertEqual(
-            From(subject).select(lambda x: x*x).average(),
+            Query(subject).select(lambda x: x*x).mean(),
             11
         )
 
@@ -68,48 +68,24 @@ class TestBasicFunctions(unittest.TestCase):
             { "value": 3 }
         ]
         self.assertEqual(
-            From(subject).select(lambda x: x["value"]).average(),
+            Query(subject).select(lambda x: x["value"]).mean(),
             2
         )
 
-    def test_concat(self):
-        
-        subjectA = [1, 2, 3]
-        subjectB = [4, 5, 6]
-        
-        self.assertListEqual(
-            From(subjectA).concat(subjectB).toList(),
-            [1, 2, 3, 4, 5, 6]
-        )
-
-        subjectA = [
-            { "value": 1},
-            { "value": 2}
-        ]
-        subjectB = [
-            { "value": 3 },
-            { "value": 4 }
-        ]
-        self.assertListEqual(
-            From(subjectA).select(lambda x: x["value"]).concat(
-                From(subjectB).select(lambda x: x["value"])
-            ).toList(),
-            [1, 2, 3, 4]
-        )
 
     def test_contains(self):
-        self.assertTrue(From([1, 2, 3, 4]).contains(2))
+        self.assertTrue(Query([1, 2, 3, 4]).contains(2))
 
-        self.assertFalse(From([1, 2, 3, 4]).contains(5))
+        self.assertFalse(Query([1, 2, 3, 4]).contains(5))
 
     def test_count(self):
         self.assertEqual(
-            From([1, 2, 3, 4, 5, 6]).count(),
+            Query([1, 2, 3, 4, 5, 6]).count(),
             6
         )
 
         self.assertEqual(
-            From([1, 2, 3, 4, 5, 6]).count(lambda x: x > 3),
+            Query([1, 2, 3, 4, 5, 6]).count(lambda x: x > 3),
             3
         )
 
@@ -123,14 +99,14 @@ class TestBasicFunctions(unittest.TestCase):
             }
         ]
         self.assertEqual(
-            From(subject).count(lambda x: x["value"] > 2),
+            Query(subject).count(lambda x: x["value"] > 2),
             1
         )
 
     def test_distinct(self):
         subject = [1, 1, 2, 3, 3, 3]
         self.assertListEqual(
-            From(subject).distinct().toList(),
+            Query(subject).distinct().to_list(),
             [1, 2, 3]
         )
 
@@ -150,14 +126,14 @@ class TestBasicFunctions(unittest.TestCase):
             }
         ]
         self.assertListEqual(
-            From(subject).distinct(lambda x: x["id"]).select(lambda x: x["value"]).toList(),
+            Query(subject).distinct(lambda x: x["id"]).select(lambda x: x["value"]).to_list(),
             [3, 4]
         )
 
         expected = [1,2,3,4]
         subject = [1,1,1,1,1,1,1,1,2,3,3,3,3,3,4]
 
-        result = From(subject).distinct().toList()
+        result = Query(subject).distinct().to_list()
 
         self.assertListEqual(expected, result)
 
@@ -183,26 +159,26 @@ class TestBasicFunctions(unittest.TestCase):
         ]
         expected = [1, 2, 3]
 
-        result = From(subject).distinct(lambda x: x["value"]).select(lambda x: x["value"]).toList()
+        result = Query(subject).distinct(lambda x: x["value"]).select(lambda x: x["value"]).to_list()
 
         self.assertListEqual(expected,result)
 
     def test_elementat(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).elementAt(2),
+            Query(subject).element_at(2),
             3
         )
 
         with self.assertRaises(IndexError):
-            From(subject).elementAt(4)
+            Query(subject).element_at(4)
 
         subject = [
             { "value": 1 },
             { "value": 2 }
         ]
         self.assertDictEqual(
-            From(subject).elementAt(0),
+            Query(subject).element_at(0),
             { "value": 1 }
         )
 
@@ -210,162 +186,80 @@ class TestBasicFunctions(unittest.TestCase):
         
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).elementAtOrNone(2),
+            Query(subject).element_at_or_none(2),
             3
         )
 
-        self.assertIsNone(From(subject).elementAtOrNone(4))
+        self.assertIsNone(Query(subject).element_at_or_none(4))
 
         subject = [
             { "value": 1 },
             { "value": 2 }
         ]
         self.assertDictEqual(
-            From(subject).elementAtOrNone(0),
+            Query(subject).element_at_or_none(0),
             { "value": 1 }
         )
 
     def test_first(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).first(lambda x: x % 2 == 0),
+            Query(subject).first(lambda x: x % 2 == 0),
             2
         )
 
         self.assertEqual(
-            From(subject).first(),
+            Query(subject).first(),
             1
         )
 
-        with self.assertRaises(NoSuchElementError):
-            From(subject).first(lambda x: x > 4)
+        with self.assertRaises(errors.NoSuchElementError):
+            Query(subject).first(lambda x: x > 4)
 
         subject = [
             { "value": 1 },
             { "value": 2 }
         ]
         self.assertDictEqual(
-            From(subject).first(lambda x: x["value"] == 2),
+            Query(subject).first(lambda x: x["value"] == 2),
             { "value": 2 }
         )
 
         expected = 2
-        result = From(self.simple).first()
+        result = Query(self.simple).first()
         self.assertEqual(expected, result)
 
         expected = 3
-        result = From(self.simple).first(lambda x: x % 2 != 0)
+        result = Query(self.simple).first(lambda x: x % 2 != 0)
         self.assertEqual(expected, result)
 
-        with self.assertRaises(NoSuchElementError):
-            From(self.simple).first(lambda x: x > 5)
+        with self.assertRaises(errors.NoSuchElementError):
+            Query(self.simple).first(lambda x: x > 5)
 
     def test_firstornone(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).firstOrNone(lambda x: x % 2 == 0),
+            Query(subject).first_or_none(lambda x: x % 2 == 0),
             2
         )
 
-        self.assertIsNone(From(subject).firstOrNone(lambda x: x > 4))
+        self.assertIsNone(Query(subject).first_or_none(lambda x: x > 4))
 
         subject = [ 
             { "value": 1 },
             { "value": 2 }
         ]
         self.assertDictEqual(
-            From(subject).first(lambda x: x["value"] == 2),
+            Query(subject).first(lambda x: x["value"] == 2),
             { "value": 2 }
         )
 
-    def test_groupby(self):
-        subject = [
-            {
-                "id": 1,
-                "data": 1
-            },
-            {
-                "id": 1,
-                "data": 2
-            },
-            {
-                "id": 2,
-                "data": 3
-            },
-            {
-                "id": 2,
-                "data": 4
-            },
-            {
-                "id": 3,
-                "data": 5
-            },
-            {
-                "id": 4,
-                "data": 6
-            }
-        ]
-
-        result = (
-            From(subject)
-            .groupBy(lambda x: x["id"], lambda x: x["data"])
-            .select(lambda x: x.values)
-            .toList()
-        )
-        expected = [[1, 2], [3, 4], [5], [6]]
-        self.assertListEqual(result, expected)
-
-        result = (
-            From(subject)
-            .groupBy(lambda x: x["id"], lambda x: x["data"])
-            .select(
-                lambda x: From(x.values).max()
-            )
-            .toList()
-        )
-        expected = [2, 4, 5, 6]
-        self.assertListEqual(result, expected)
-
-        subject = [
-            {
-                "age": 10,
-                "name": "Steven"
-            }, {
-                "age": 10,
-                "name": "Johan"
-            }, {
-                "age": 11,
-                "name": "Lars"
-            }
-        ]
-        
-        # Keys
-        self.assertListEqual(
-
-            From(subject).groupBy(
-                lambda x: x["age"], 
-                transform = lambda x: x["name"]
-            ).select(lambda x: x.key).toList(),
-
-            [10, 11]
-        )
-
-        # Names
-        self.assertListEqual(
-            
-            From(subject).groupBy(
-                lambda x: x["age"],
-                transform=lambda x: x["name"]
-            ).select(lambda x: x.values).toList(),
-
-            [ ["Steven", "Johan" ], [ "Lars" ] ]
-        )
 
     def test_intersect(self):
         subject1 = [1,2,3,4]
         subject2 = [3,4,5,6]
 
-        result = From(subject1).intersect(subject2).toList()
+        result = Query(subject1).intersect(subject2).to_list()
         expected = [3,4]
         self.assertListEqual(result,expected)
 
@@ -387,14 +281,14 @@ class TestBasicFunctions(unittest.TestCase):
                 "value": 5
             }
         ]
-        result = From(subjectA).intersect(subjectB, key=lambda x: x["id"]).select(lambda x: x["value"]).toList()
+        result = Query(subjectA).intersect(subjectB, key=lambda x: x["id"]).select(lambda x: x["value"]).to_list()
         expected = [4]
         self.assertListEqual(expected, result)
 
         subjectA = [1, 2, 3, 4]
         subjectB = [3, 4, 5, 6]
         self.assertListEqual(
-            From(subjectA).intersect(subjectB).toList(),
+            Query(subjectA).intersect(subjectB).to_list(),
             [3, 4]
         )
 
@@ -417,43 +311,43 @@ class TestBasicFunctions(unittest.TestCase):
             }
         ]
         self.assertListEqual(
-            From(subjectA).intersect(subjectB, key=lambda x: x["id"]).select(lambda x: x["value"]).toList(),
+            Query(subjectA).intersect(subjectB, key=lambda x: x["id"]).select(lambda x: x["value"]).to_list(),
             [4]
         )
 
     def test_last(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).last(lambda x: x < 4),
+            Query(subject).last(lambda x: x < 4),
             3
         )
 
         self.assertEqual(
-            From(subject).last(),
+            Query(subject).last(),
             4
         )
 
-        with self.assertRaises(NoSuchElementError):
-            From(subject).last(lambda x: x > 4)
+        with self.assertRaises(errors.NoSuchElementError):
+            Query(subject).last(lambda x: x > 4)
 
         subject = [
             { "value": 1 },
             { "value": 2 }
         ]
         self.assertDictEqual(
-            From(subject).last(lambda x: x["value"] > 0),
+            Query(subject).last(lambda x: x["value"] > 0),
             { "value": 2 }
         )
 
     def test_lastornone(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).lastOrNone(lambda x: x % 2 == 0),
+            Query(subject).last_or_none(lambda x: x % 2 == 0),
             4
         )
 
         self.assertIsNone(
-            From(subject).lastOrNone(lambda x: x > 4)
+            Query(subject).last_or_none(lambda x: x > 4)
         )
 
         subject = [ 
@@ -461,14 +355,14 @@ class TestBasicFunctions(unittest.TestCase):
             { "value": 2 }
         ]
         self.assertDictEqual(
-            From(subject).last(lambda x: x["value"] > 0),
+            Query(subject).last(lambda x: x["value"] > 0),
             { "value": 2 }
         )
 
     def test_argmax(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).argmax(lambda x: x),
+            Query(subject).argmax(lambda x: x),
             4
         )
 
@@ -477,14 +371,14 @@ class TestBasicFunctions(unittest.TestCase):
             { "value" : 2 }
         ]
         self.assertEqual(
-            From(subject).argmax(lambda x: x["value"]),
+            Query(subject).argmax(lambda x: x["value"]),
             { "value": 2 }
         )
 
     def test_max(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).max(),
+            Query(subject).max(),
             4
         )
 
@@ -493,14 +387,14 @@ class TestBasicFunctions(unittest.TestCase):
             { "value" : 2 }
         ]
         self.assertEqual(
-            From(subject).select(lambda x: x["value"]).max(),
+            Query(subject).select(lambda x: x["value"]).max(),
             2
         )
 
     def test_argmin(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).argmin(lambda x: x),
+            Query(subject).argmin(lambda x: x),
             1
         )
 
@@ -509,14 +403,14 @@ class TestBasicFunctions(unittest.TestCase):
             { "value" : 2 }
         ]
         self.assertEqual(
-            From(subject).argmin(lambda x: x["value"]),
+            Query(subject).argmin(lambda x: x["value"]),
             { "value": 1 }
         )
 
     def test_min(self):
         subject = [1, 2, 3, 4]
         self.assertEqual(
-            From(subject).min(),
+            Query(subject).min(),
             1
         )
 
@@ -525,7 +419,7 @@ class TestBasicFunctions(unittest.TestCase):
             { "value" : 2 }
         ]
         self.assertEqual(
-            From(subject).select(lambda x: x["value"]).min(),
+            Query(subject).select(lambda x: x["value"]).min(),
             1
         )
 
@@ -540,7 +434,7 @@ class TestBasicFunctions(unittest.TestCase):
             }
         ]
         self.assertListEqual(
-            From(subject).select(lambda x: x["value"]).toList(),
+            Query(subject).select(lambda x: x["value"]).to_list(),
             [2, 3]
         )
 
@@ -551,15 +445,15 @@ class TestBasicFunctions(unittest.TestCase):
             }
         
         self.assertListEqual(
-            From(subject).select(shape).toList(),
+            Query(subject).select(shape).to_list(),
             [ {"value": 1}, {"value": 2} ]
         )
 
-    def test_selectmany(self):
+    def test_flatten(self):
         expected = [1, 2, 3, 4]
-        obj = From([[1, 2], [3, 4]])
+        obj = Query([[1, 2], [3, 4]])
 
-        result = obj.selectMany().toList()
+        result = obj.flatten().to_list()
 
         self.assertListEqual(expected, result)
 
@@ -568,7 +462,7 @@ class TestBasicFunctions(unittest.TestCase):
             [5, 6, 7, 8]
         ]
         self.assertListEqual(
-            From(subject).selectMany().toList(),
+            Query(subject).flatten().to_list(),
             [1, 2, 3, 4, 5, 6, 7, 8]
         )
 
@@ -577,19 +471,19 @@ class TestBasicFunctions(unittest.TestCase):
             [{"value": 3}, {"value": 4}]
         ]
         self.assertListEqual(
-            From(subject).selectMany(lambda x: x["value"]).toList(),
+            Query(subject).flatten().select(lambda x: x["value"]).to_list(),
             [1, 2, 3, 4]
         )
 
     def test_sum(self):
         subject = [1, 2, 3, 4, 5]
         self.assertEqual(
-            From(subject).sum(),
+            Query(subject).sum(),
             15
         )
 
         self.assertEqual(
-            From(subject).select(lambda x: x*x).sum(),
+            Query(subject).select(lambda x: x*x).sum(),
             55
         )
 
@@ -599,42 +493,33 @@ class TestBasicFunctions(unittest.TestCase):
             { "value": 3 }
         ]
         self.assertEqual(
-            From(subject).select(lambda x: x["value"]).sum(),
+            Query(subject).select(lambda x: x["value"]).sum(),
             6
         )
 
     def test_tolist(self):
         self.assertListEqual(
-            From([1, 2, 3, 4]).select(lambda x: x*x).toList(),
+            Query([1, 2, 3, 4]).select(lambda x: x*x).to_list(),
             [1, 4, 9, 16]
         )
 
         self.assertListEqual(
-            From([1, 2, 3, 4]).toList(),
+            Query([1, 2, 3, 4]).to_list(),
             [1, 2, 3, 4]
         )
 
-    def test_foreach(self):
-        res = []
-
-        subject = [1, 2, 3]
-        From(subject).forEach(lambda x: res.append(x))
-        self.assertListEqual(
-            res,
-            subject
-        )
 
     def test_where(self):
         expected = [2, 4]
-        obj = From(self.simple)
+        obj = Query(self.simple)
 
-        result = obj.where(lambda x: x % 2 == 0).toList()
+        result = obj.where(lambda x: x % 2 == 0).to_list()
 
         self.assertListEqual(expected, result)
 
         subject = [1, 2, 3, 4, 5, 6]
         self.assertListEqual(
-            From(subject).where(lambda x: x > 3).toList(),
+            Query(subject).where(lambda x: x > 3).to_list(),
             [4, 5, 6]
         )
 
@@ -643,139 +528,21 @@ class TestBasicFunctions(unittest.TestCase):
             { "value": 3 }
         ]
         self.assertListEqual(
-            From(subject).where(lambda x: x["value"] == 3).select(lambda x: x["value"]).toList(),
+            Query(subject).where(lambda x: x["value"] == 3).select(lambda x: x["value"]).to_list(),
             [3]
         )
 
-    def test_groupjoin(self):
-        grades = [
-            {
-                "userid": 1,
-                "grade": "A"
-            }, {
-                "userid": 1,
-                "grade": "B"
-            }, {
-                "userid": 2,
-                "grade": "B"
-            }, {
-                "userid": 2,
-                "grade": "B"
-            }
-        ]
-        students = [
-            {
-                "id": 1,
-                "name": "Jakob"
-            }, {
-                "id": 2,
-                "name": "Johan"
-            }
-        ]
-        
-        self.assertListEqual(
-            
-            From(students).groupJoin(
-                grades,
-                innerKey = lambda x: x["id"],
-                outerKey = lambda x: x["userid"],
-                innerTransform = lambda x: x["name"],
-                outerTransform = lambda x: x["grade"]
-            )
-            .select(lambda x: x.inner).toList(),
-            
-            ['Jakob', 'Johan']
-        )
-
-        self.assertListEqual(
-
-            From(students).groupJoin(
-                grades,
-                innerKey = lambda x: x["id"],
-                outerKey = lambda x: x["userid"],
-                innerTransform = lambda x: x["name"],
-                outerTransform = lambda x: x["grade"]
-            ).select(lambda x: x.outer).toList(),
-
-            [ ['A', 'B'], ['B', 'B'] ]
-        )
-
-        subjA = [1, 2, 3]
-        subjB = [2, 2, 3, 4]
-
-        result = From(subjA).groupJoin(
-            subjB,
-            lambda x: x,
-            lambda x: x,
-            lambda x: x,
-            lambda x: x
-        ).select(lambda x: x.outer).toList()
-        expected = [[], [2, 2], [3]]
-        self.assertListEqual(expected, result)
-
-        grades = [
-            {
-                "userid": 1,
-                "grade": "A"
-            }, {
-                "userid": 1,
-                "grade": "B"
-            }, {
-                "userid": 2,
-                "grade": "B"
-            }, {
-                "userid": 2,
-                "grade": "B"
-            }
-        ]
-        students = [
-            {
-                "id": 1,
-                "name": "Jakob"
-            }, {
-                "id": 2,
-                "name": "Johan"
-            }
-        ]
-        names = From(students).groupJoin(
-            grades,
-            innerKey = lambda x: x["id"],
-            outerKey = lambda x: x["userid"],
-            innerTransform = lambda x: x["name"],
-            outerTransform = lambda x: x["grade"]
-        ).select(lambda x: x.inner).toList()
-
-        expected = ["Jakob", "Johan"]
-        self.assertListEqual(
-            names,
-            expected
-        )
-
-        grades = From(students).groupJoin(
-            grades,
-            innerKey = lambda x: x["id"],
-            outerKey = lambda x: x["userid"],
-            innerTransform = lambda x: x["name"],
-            outerTransform = lambda x: x["grade"]
-        ).select(lambda x: x.outer).toList()
-
-        expected = [["A","B"], ["B","B"]]
-        self.assertListEqual(
-            grades,
-            expected
-        )
-
     def test_join(self):
         subjA = [1, 2, 3, 4, 5]
         subjB = [2, 3, 4, 5, 6]
         self.assertListEqual(
             
-            From(subjA).join(
+            Query(subjA).join(
                 subjB,
                 lambda x: x,
                 lambda x: x+1,
                 lambda x, y: {"inner": x, "outer": y}
-            ).toList(),
+            ).to_list(),
 
             [
                 { "inner": 3, "outer": 2},
@@ -826,14 +593,14 @@ class TestBasicFunctions(unittest.TestCase):
         ]
 
         result = (
-            From(subject1)
+            Query(subject1)
             .join(
                 subject2,
                 lambda x: x["id"],
                 lambda x: x["id"],
                 lambda inner, outer: { "A": inner["A"], "B": outer["B"] }
             )
-            .toList()
+            .to_list()
         )
         expected = [
             {
@@ -857,77 +624,77 @@ class TestBasicFunctions(unittest.TestCase):
 
     def test_take(self):
         self.assertListEqual(
-            From([1, 2, 3]).take(2).toList(),
+            Query([1, 2, 3]).take(2).to_list(),
             [1, 2]
         )
 
     def test_takewhile(self):
         self.assertListEqual(
-            From([1, 2, 3, 4, 5, 6]).takeWhile(lambda x: x % 3 != 0).toList(),
+            Query([1, 2, 3, 4, 5, 6]).take_while(lambda x: x % 3 != 0).to_list(),
             [1, 2]
         )
 
     def test_order(self):
         self.assertListEqual(
-            From([1, 2, 4, 3, 7, 6, 5]).order(descending=True).toList(),
+            Query([1, 2, 4, 3, 7, 6, 5]).order(descending=True).to_list(),
             [7, 6, 5, 4, 3, 2, 1]
         )
 
         self.assertListEqual(
-            From([1, 2, 4, 3, 7, 6, 5]).order().toList(),
+            Query([1, 2, 4, 3, 7, 6, 5]).order().to_list(),
             [1, 2, 3, 4, 5, 6, 7]
         )
 
         self.assertListEqual(
-            From([1, 2, 4, 3, 7, 6, 5]).order(key=lambda x: x % 3).toList(),
+            Query([1, 2, 4, 3, 7, 6, 5]).order(value=lambda x: x % 3).to_list(),
             [3, 6, 1, 4, 7, 2, 5]
         )
 
     def test_union(self):
         self.assertListEqual(
-            From([1, 2, 3]).union([3, 4, 5]).toList(),
+            Query([1, 2, 3]).union([3, 4, 5]).to_list(),
             [1, 2, 3, 4, 5]
         )
 
         self.assertListEqual(
-            From([1, 2, 3]).union([3, 4, 5], key = lambda x: x % 4).toList(),
+            Query([1, 2, 3]).union([3, 4, 5], value = lambda x: x % 4).to_list(),
             [1, 2, 3, 4] # Note 5 == 2 in modulo 4
         )
 
         self.assertListEqual(
-            From([1, 2, 3]).union([3, 4, 5]).select(lambda x: x+1).toList(),
+            Query([1, 2, 3]).union([3, 4, 5]).select(lambda x: x+1).to_list(),
             [2, 3, 4, 5, 6]
         )
 
     def test_wrapper(self):
         with self.assertRaises(ValueError):
-            From(1)
+            Query(1)
 
-        From("a")
-        From([1,2,3])
+        Query("a")
+        Query([1,2,3])
 
         self.assertTrue(True)
 
     def test_skip(self):
         self.assertListEqual(
-            From([1,2,3,4,5,6,7]).skip(3).toList(),
+            Query([1,2,3,4,5,6,7]).skip(3).to_list(),
             [4,5,6,7]
         )
 
     def test_skipWhile(self):
         self.assertListEqual(
-            From([1,2,3,4,5,6,7]).skipWhile(lambda x: x < 3).toList(),
+            Query([1,2,3,4,5,6,7]).skip_while(lambda x: x < 3).to_list(),
             [3,4,5,6,7]
         )
 
         self.assertListEqual(
-            From([1,2,3,4,5,6,7]).skipWhile(lambda x: x % 3 != 0).toList(),
+            Query([1,2,3,4,5,6,7]).skip_while(lambda x: x % 3 != 0).to_list(),
             [3,4,5,6,7]
         )
 
     def test_toDict(self):
         self.assertDictEqual(
-            From([1,2,3,4]).toDict(lambda x: str(x*x)),
+            Query([1,2,3,4]).to_dict(lambda x: str(x*x)),
             {
                 '1': 1,
                 '4': 2,
@@ -937,7 +704,7 @@ class TestBasicFunctions(unittest.TestCase):
         )
 
         self.assertDictEqual(
-            From([1,2,3,4]).toDict(lambda x: str(x), transform = lambda x: x*x),
+            Query([1,2,3,4]).to_dict(lambda x: str(x), value = lambda x: x*x),
             {
                 '1': 1,
                 '2': 4,
@@ -947,4 +714,4 @@ class TestBasicFunctions(unittest.TestCase):
         )
 
         with self.assertRaises(KeyError):
-            From([1,2,3,4]).toDict(lambda x: str(x % 3))
\ No newline at end of file
+            Query([1,2,3,4]).to_dict(lambda x: str(x % 3))
\ No newline at end of file
